http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/BucketServerLocation.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/BucketServerLocation.hpp 
b/src/cppcache/src/BucketServerLocation.hpp
index 646b14b..71f66c2 100644
--- a/src/cppcache/src/BucketServerLocation.hpp
+++ b/src/cppcache/src/BucketServerLocation.hpp
@@ -20,7 +20,9 @@
 #include "ServerLocation.hpp"
 #include <string>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 _GF_PTR_DEF_(BucketServerLocation, BucketServerLocationPtr)
 
 class BucketServerLocation : public ServerLocation {
@@ -91,7 +93,7 @@ class BucketServerLocation : public ServerLocation {
 
   inline int8 getVersion() const { return m_version; }
 
-  void toData(gemfire::DataOutput& output) const {
+  void toData(apache::geode::client::DataOutput& output) const {
     ServerLocation::toData(output);
     output.writeInt(m_bucketId);
     output.writeBoolean(m_isPrimary);
@@ -104,7 +106,7 @@ class BucketServerLocation : public ServerLocation {
     }
   }
 
-  BucketServerLocation* fromData(gemfire::DataInput& input) {
+  BucketServerLocation* fromData(apache::geode::client::DataInput& input) {
     ServerLocation::fromData(input);
     input.readInt((int32_t*)&m_bucketId);
     input.readBoolean(&m_isPrimary);
@@ -168,6 +170,8 @@ class BucketServerLocation : public ServerLocation {
 
   inline CacheableStringArrayPtr getServerGroups() { return m_serverGroups; }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/Cache.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Cache.cpp b/src/cppcache/src/Cache.cpp
index f2669ab..a8d283a 100644
--- a/src/cppcache/src/Cache.cpp
+++ b/src/cppcache/src/Cache.cpp
@@ -29,7 +29,7 @@
 #include <gfcpp/PoolManager.hpp>
 #include <PdxInstanceFactoryImpl.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 extern bool Cache_CreatedFromCacheFactory;
 extern ACE_Recursive_Thread_Mutex* g_disconnectLock;
@@ -82,8 +82,8 @@ void Cache::close(bool keepalive) {
       Cache_CreatedFromCacheFactory = false;
       DistributedSystem::disconnect();
     }
-  } catch (const gemfire::NotConnectedException&) {
-  } catch (const gemfire::Exception&) {
+  } catch (const apache::geode::client::NotConnectedException&) {
+  } catch (const apache::geode::client::Exception&) {
   } catch (...) {
   }
 }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheAttributes.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheAttributes.cpp 
b/src/cppcache/src/CacheAttributes.cpp
index c6c1b93..75b906a 100644
--- a/src/cppcache/src/CacheAttributes.cpp
+++ b/src/cppcache/src/CacheAttributes.cpp
@@ -21,7 +21,7 @@
 #include <gfcpp/GemfireTypeIds.hpp>
 #include <gfcpp/CacheAttributes.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 CacheAttributes::CacheAttributes()
     : m_redundancyLevel(0), m_endpoints(NULL), m_cacheMode(false) {}
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheConfig.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheConfig.cpp b/src/cppcache/src/CacheConfig.cpp
index f3e3953..530df4e 100644
--- a/src/cppcache/src/CacheConfig.cpp
+++ b/src/cppcache/src/CacheConfig.cpp
@@ -28,7 +28,9 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 //////////////////////////////////////////////////////////////////////
 // Construction/Destruction
@@ -132,4 +134,6 @@ bool CacheConfig::parseAttributes(const char* name, 
xmlNode* node) {
 }
 
 RegionConfigMapT& CacheConfig::getRegionList() { return m_regionList; }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheConfig.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheConfig.hpp b/src/cppcache/src/CacheConfig.hpp
index 8e4932b..1f7abf3 100644
--- a/src/cppcache/src/CacheConfig.hpp
+++ b/src/cppcache/src/CacheConfig.hpp
@@ -46,7 +46,9 @@ struct _xmlDoc;
 typedef struct _xmlDoc xmlDoc;
 typedef struct _xmlNode xmlNode;
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 typedef std::map<std::string, RegionConfigPtr> RegionConfigMapT;
 
@@ -72,5 +74,7 @@ class CPPCACHE_EXPORT CacheConfig {
 
   RegionConfigMapT m_regionList;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // 
!defined(AFX_CacheConfig_H__48B95D79_F676_4F8A_8522_8B172DB33F7E__INCLUDED_)

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheFactory.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheFactory.cpp 
b/src/cppcache/src/CacheFactory.cpp
index 4cf3504..92e9a6f 100644
--- a/src/cppcache/src/CacheFactory.cpp
+++ b/src/cppcache/src/CacheFactory.cpp
@@ -46,7 +46,9 @@ extern ACE_Recursive_Thread_Mutex* g_disconnectLock;
 
 bool Cache_CreatedFromCacheFactory = false;
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 ACE_Recursive_Thread_Mutex g_cfLock;
 
 typedef std::map<std::string, CachePtr> StringToCachePtrMap;
@@ -283,9 +285,9 @@ CachePtr CacheFactory::create(const char* name,
         cptr->m_cacheImpl->initServices();
       }
     }
-  } catch (const gemfire::RegionExistsException&) {
+  } catch (const apache::geode::client::RegionExistsException&) {
     LOGWARN("Attempt to create existing regions declaratively");
-  } catch (const gemfire::Exception&) {
+  } catch (const apache::geode::client::Exception&) {
     if (!cptr->isClosed()) {
       cptr->close();
       cptr = NULLPTR;
@@ -296,7 +298,8 @@ CachePtr CacheFactory::create(const char* name,
       cptr->close();
       cptr = NULLPTR;
     }
-    throw gemfire::UnknownException("Exception thrown in 
CacheFactory::create");
+    throw apache::geode::client::UnknownException(
+        "Exception thrown in CacheFactory::create");
   }
 
   return cptr;
@@ -575,4 +578,6 @@ CacheFactoryPtr CacheFactory::setPdxReadSerialized(bool 
prs) {
   CacheFactoryPtr cfPtr(this);
   return cfPtr;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheImpl.cpp b/src/cppcache/src/CacheImpl.cpp
index 76b3586..4e23e97 100644
--- a/src/cppcache/src/CacheImpl.cpp
+++ b/src/cppcache/src/CacheImpl.cpp
@@ -41,7 +41,7 @@
 #include "InternalCacheTransactionManager2PCImpl.hpp"
 #include "PdxTypeRegistry.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 ExpiryTaskManager* CacheImpl::expiryTaskManager = NULL;
 CacheImpl* CacheImpl::s_instance = NULL;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheListener.cpp 
b/src/cppcache/src/CacheListener.cpp
index a392221..bb74135 100644
--- a/src/cppcache/src/CacheListener.cpp
+++ b/src/cppcache/src/CacheListener.cpp
@@ -20,7 +20,9 @@
 #include <gfcpp/EntryEvent.hpp>
 #include <gfcpp/RegionEvent.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 CacheListener::CacheListener() {}
 
@@ -45,4 +47,6 @@ void CacheListener::afterRegionClear(const RegionEvent& 
event) {}
 void CacheListener::afterRegionLive(const RegionEvent& event) {}
 
 void CacheListener::afterRegionDisconnected(const RegionPtr& region) {}
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheLoader.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheLoader.cpp b/src/cppcache/src/CacheLoader.cpp
index 9d8fe4a..f198b43 100644
--- a/src/cppcache/src/CacheLoader.cpp
+++ b/src/cppcache/src/CacheLoader.cpp
@@ -20,7 +20,7 @@
 #include <RegionInternal.hpp>
 #include <MapEntry.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 CacheLoader::CacheLoader() {}
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CachePerfStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CachePerfStats.hpp 
b/src/cppcache/src/CachePerfStats.hpp
index 2b8d30d..d64400c 100644
--- a/src/cppcache/src/CachePerfStats.hpp
+++ b/src/cppcache/src/CachePerfStats.hpp
@@ -22,7 +22,9 @@
 #include <gfcpp/statistics/Statistics.hpp>
 #include <gfcpp/statistics/StatisticsFactory.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 using namespace gemfire_statistics;
 
@@ -352,6 +354,8 @@ class CPPCACHE_EXPORT CachePerfStats {
   int32_t m_pdxDeserializationsId;
   int32_t m_pdxDeserializedBytesId;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_CACHEPERFSTATS_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheRegionHelper.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheRegionHelper.hpp 
b/src/cppcache/src/CacheRegionHelper.hpp
index fab9ef3..d04bc55 100644
--- a/src/cppcache/src/CacheRegionHelper.hpp
+++ b/src/cppcache/src/CacheRegionHelper.hpp
@@ -26,7 +26,9 @@
 #include "CacheImpl.hpp"
 #include <gfcpp/DistributedSystem.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CacheRegionHelper {
   /**
@@ -42,5 +44,7 @@ class CacheRegionHelper {
     return DistributedSystem::m_impl;
   }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // ifndef __GEMFIRE_IMPL_CACHEHELPER_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheStatistics.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheStatistics.cpp 
b/src/cppcache/src/CacheStatistics.cpp
index ffc8b45..4ca06d0 100644
--- a/src/cppcache/src/CacheStatistics.cpp
+++ b/src/cppcache/src/CacheStatistics.cpp
@@ -18,7 +18,7 @@
 #include <gfcpp/CacheStatistics.hpp>
 #include <HostAsm.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 CacheStatistics::CacheStatistics() {
   m_lastModifiedTime = 0;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheTransactionManager.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheTransactionManager.cpp 
b/src/cppcache/src/CacheTransactionManager.cpp
index 7ca8036..ee82d5c 100644
--- a/src/cppcache/src/CacheTransactionManager.cpp
+++ b/src/cppcache/src/CacheTransactionManager.cpp
@@ -17,7 +17,11 @@
 
 #include <gfcpp/CacheTransactionManager.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 CacheTransactionManager::CacheTransactionManager() {}
 CacheTransactionManager::~CacheTransactionManager() {}
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheTransactionManagerImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheTransactionManagerImpl.cpp 
b/src/cppcache/src/CacheTransactionManagerImpl.cpp
index 80fb42b..251d14f 100644
--- a/src/cppcache/src/CacheTransactionManagerImpl.cpp
+++ b/src/cppcache/src/CacheTransactionManagerImpl.cpp
@@ -34,7 +34,9 @@
 #include <gfcpp/PoolManager.hpp>
 #include "TXCleaner.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 CacheTransactionManagerImpl::CacheTransactionManagerImpl(Cache* cache)
     : m_cache(cache), m_txCond(m_suspendedTxLock) {}
@@ -668,4 +670,6 @@ staticCast<TransactionListenerPtr>(*iter);
         }
 }
 */
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheTransactionManagerImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheTransactionManagerImpl.hpp 
b/src/cppcache/src/CacheTransactionManagerImpl.hpp
index d012b5c..b6f9f8c 100644
--- a/src/cppcache/src/CacheTransactionManagerImpl.hpp
+++ b/src/cppcache/src/CacheTransactionManagerImpl.hpp
@@ -30,13 +30,15 @@
 #include <gfcpp/Log.hpp>
 #include "SuspendedTxExpiryHandler.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 enum status { STATUS_COMMITTED = 3, STATUS_ROLLEDBACK = 4 };
 enum commitOp { BEFORE_COMMIT, AFTER_COMMIT };
 
 class CacheTransactionManagerImpl
-    : public virtual gemfire::CacheTransactionManager {
+    : public virtual apache::geode::client::CacheTransactionManager {
  public:
   CacheTransactionManagerImpl(Cache* cache);
   virtual ~CacheTransactionManagerImpl();
@@ -102,6 +104,8 @@ class CacheTransactionManagerImpl
 
   friend class TXCleaner;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif /* CACHETRANSACTIONMANAGERIMPL_H_ */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheWriter.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheWriter.cpp b/src/cppcache/src/CacheWriter.cpp
index 4c46551..32715e5 100644
--- a/src/cppcache/src/CacheWriter.cpp
+++ b/src/cppcache/src/CacheWriter.cpp
@@ -20,7 +20,9 @@
 #include <gfcpp/EntryEvent.hpp>
 #include <gfcpp/RegionEvent.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 CacheWriter::CacheWriter() {}
 
@@ -36,4 +38,6 @@ bool CacheWriter::beforeDestroy(const EntryEvent& event) { 
return true; }
 
 bool CacheWriter::beforeRegionDestroy(const RegionEvent& event) { return true; 
}
 bool CacheWriter::beforeRegionClear(const RegionEvent& event) { return true; }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheXml.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheXml.cpp b/src/cppcache/src/CacheXml.cpp
index a365e0d..4f29352 100644
--- a/src/cppcache/src/CacheXml.cpp
+++ b/src/cppcache/src/CacheXml.cpp
@@ -17,7 +17,7 @@
 
 #include "CacheXml.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 CacheXml::CacheXml() {
   /** The name of the <code>cache</code> element */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheXml.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheXml.hpp b/src/cppcache/src/CacheXml.hpp
index 4b49443..367cfc3 100644
--- a/src/cppcache/src/CacheXml.hpp
+++ b/src/cppcache/src/CacheXml.hpp
@@ -19,7 +19,9 @@
 
 #include <gfcpp/gfcpp_globals.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CPPCACHE_EXPORT CacheXml {
  public:
@@ -208,6 +210,7 @@ class CPPCACHE_EXPORT CacheXml {
  public:
   CacheXml();
 };
-
-};      // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // ifndef __GEMFIRE_CACHEXML_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheXmlCreation.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheXmlCreation.cpp 
b/src/cppcache/src/CacheXmlCreation.cpp
index 0565bbf..21a8f32 100644
--- a/src/cppcache/src/CacheXmlCreation.cpp
+++ b/src/cppcache/src/CacheXmlCreation.cpp
@@ -20,7 +20,7 @@
 #include "CacheImpl.hpp"
 #include "PoolAttributes.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 void CacheXmlCreation::addRootRegion(RegionXmlCreation* root) {
   rootRegions.push_back(root);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheXmlCreation.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheXmlCreation.hpp 
b/src/cppcache/src/CacheXmlCreation.hpp
index 4492433..cc002b7 100644
--- a/src/cppcache/src/CacheXmlCreation.hpp
+++ b/src/cppcache/src/CacheXmlCreation.hpp
@@ -23,7 +23,9 @@
 #include "PoolXmlCreation.hpp"
 #include <vector>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class Cache;
 /**
@@ -87,6 +89,8 @@ class CPPCACHE_EXPORT CacheXmlCreation {
   bool m_pdxIgnoreUnreadFields;
   bool m_readPdxSerialized;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // #ifndef  _GEMFIRE_CACHEXMLCREATION_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheXmlParser.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheXmlParser.cpp 
b/src/cppcache/src/CacheXmlParser.cpp
index e9f3201..c8643ec 100644
--- a/src/cppcache/src/CacheXmlParser.cpp
+++ b/src/cppcache/src/CacheXmlParser.cpp
@@ -27,7 +27,7 @@
 #include <dlfcn.h>
 #endif
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 namespace gemfire_impl {
 void* getFactoryFunc(const char* lib, const char* funcName);
@@ -910,11 +910,13 @@ void CacheXmlParser::startRegionAttributes(const 
xmlChar** atts) {
         i++;
         char* diskPolicy = (char*)atts[i];
         if (strcmp(OVERFLOWS, diskPolicy) == 0) {
-          attrsFactory->setDiskPolicy(gemfire::DiskPolicyType::OVERFLOWS);
+          attrsFactory->setDiskPolicy(
+              apache::geode::client::DiskPolicyType::OVERFLOWS);
         } else if (strcmp(PERSIST, diskPolicy) == 0) {
           throw IllegalStateException(" persistence feature is not supported");
         } else if (strcmp(NONE, diskPolicy) == 0) {
-          attrsFactory->setDiskPolicy(gemfire::DiskPolicyType::NONE);
+          attrsFactory->setDiskPolicy(
+              apache::geode::client::DiskPolicyType::NONE);
         } else {
           char* name = (char*)atts[i];
           std::string temp(name);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheXmlParser.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheXmlParser.hpp 
b/src/cppcache/src/CacheXmlParser.hpp
index c955180..b7f0b00 100644
--- a/src/cppcache/src/CacheXmlParser.hpp
+++ b/src/cppcache/src/CacheXmlParser.hpp
@@ -33,7 +33,9 @@
 #include <gfcpp/ExceptionTypes.hpp>
 #include <gfcpp/RegionShortcut.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 // Factory function typedefs to register the managed
 // cacheloader/writer/listener/resolver
@@ -148,6 +150,7 @@ class CPPCACHE_EXPORT CacheXmlParser : public CacheXml {
   static LibraryCacheWriterFn managedCacheWriterFn;
   static LibraryPersistenceManagerFn managedPersistenceManagerFn;
 };
-
-};      // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // ifndef __GEMFIRE_CACHEXMLPARSER_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableBuiltins.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableBuiltins.cpp 
b/src/cppcache/src/CacheableBuiltins.cpp
index 8cab82f..6fabf36 100644
--- a/src/cppcache/src/CacheableBuiltins.cpp
+++ b/src/cppcache/src/CacheableBuiltins.cpp
@@ -22,7 +22,9 @@ extern "C" {
 #include <stdarg.h>
 }
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 int gf_sprintf(char* buffer, const char* fmt, ...) {
   va_list args;
@@ -56,4 +58,6 @@ _GF_CACHEABLE_KEY_DEF_(CacheableInt16, "%" PRIi16);
 _GF_CACHEABLE_KEY_DEF_(CacheableInt32, "%" PRIi32);
 _GF_CACHEABLE_KEY_DEF_(CacheableInt64, "%" PRIi64);
 _GF_CACHEABLE_KEY_DEF_(CacheableWideChar, "%lc");
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableDate.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableDate.cpp 
b/src/cppcache/src/CacheableDate.cpp
index d504e4b..ee193ea 100644
--- a/src/cppcache/src/CacheableDate.cpp
+++ b/src/cppcache/src/CacheableDate.cpp
@@ -26,7 +26,9 @@
 #include <cwchar>
 #include <ace/OS.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void CacheableDate::toData(DataOutput& output) const {
   int64_t msec = static_cast<int64_t>(m_timevalue.tv_sec);
@@ -138,4 +140,6 @@ int32_t CacheableDate::logString(char* buffer, int32_t 
maxLength) const {
                           "CacheableDate (mm/dd/yyyy) ( %d/%d/%d )",
                           date.tm_mon + 1, date.tm_mday, date.tm_year + 1900);
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableEnum.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableEnum.cpp 
b/src/cppcache/src/CacheableEnum.cpp
index 9768a73..39c0254 100644
--- a/src/cppcache/src/CacheableEnum.cpp
+++ b/src/cppcache/src/CacheableEnum.cpp
@@ -20,7 +20,9 @@
 #include <GemfireTypeIdsImpl.hpp>
 #include <EnumInfo.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 CacheableEnum::~CacheableEnum() {}
 
@@ -37,7 +39,7 @@ CacheableEnum::CacheableEnum(const char* enumClassName, const 
char* enumName,
   m_enumName = CacheableString::create(enumName);
 }
 
-void CacheableEnum::toData(gemfire::DataOutput& output) const {
+void CacheableEnum::toData(apache::geode::client::DataOutput& output) const {
   int enumVal = PdxHelper::getEnumValue(m_enumClassName->asChar(),
                                         m_enumName->asChar(), m_ordinal);
   output.write(static_cast<int8_t>(GemfireTypeIds::CacheableEnum));
@@ -45,7 +47,7 @@ void CacheableEnum::toData(gemfire::DataOutput& output) const 
{
   output.writeArrayLen(enumVal & 0xFFFFFF);
 }
 
-Serializable* CacheableEnum::fromData(gemfire::DataInput& input) {
+Serializable* CacheableEnum::fromData(apache::geode::client::DataInput& input) 
{
   int8_t dsId;
   input.read(&dsId);
   int32_t arrLen;
@@ -100,4 +102,6 @@ bool CacheableEnum::operator==(const CacheableKey& other) 
const {
   }
   return true;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableFileName.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableFileName.cpp 
b/src/cppcache/src/CacheableFileName.cpp
index 3693023..c2b9c55 100644
--- a/src/cppcache/src/CacheableFileName.cpp
+++ b/src/cppcache/src/CacheableFileName.cpp
@@ -22,7 +22,9 @@
 #include <ace/ACE.h>
 #include <ace/OS.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void CacheableFileName::toData(DataOutput& output) const {
   output.write(m_type);
@@ -65,4 +67,6 @@ uint32_t CacheableFileName::hashcode() const {
   }
   return m_hashcode;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableKey.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableKey.cpp 
b/src/cppcache/src/CacheableKey.cpp
index 8877382..065aea2 100644
--- a/src/cppcache/src/CacheableKey.cpp
+++ b/src/cppcache/src/CacheableKey.cpp
@@ -22,10 +22,14 @@
 #include <ace/OS.h>
 #include <typeinfo>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 int32_t CacheableKey::logString(char* buffer, int32_t maxLength) const {
   return ACE_OS::snprintf(buffer, maxLength, "%s( @0x%08lX )",
                           typeid(*this).name(), (unsigned long)this);
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableObjectArray.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableObjectArray.cpp 
b/src/cppcache/src/CacheableObjectArray.cpp
index 5cda068..29e821d 100644
--- a/src/cppcache/src/CacheableObjectArray.cpp
+++ b/src/cppcache/src/CacheableObjectArray.cpp
@@ -21,7 +21,9 @@
 #include <gfcpp/GemfireTypeIds.hpp>
 #include <GemfireTypeIdsImpl.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void CacheableObjectArray::toData(DataOutput& output) const {
   int32_t len = size();
@@ -66,4 +68,6 @@ uint32_t CacheableObjectArray::objectSize() const {
   }
   return size;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableObjectPartList.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableObjectPartList.cpp 
b/src/cppcache/src/CacheableObjectPartList.cpp
index ff00248..e1d42a6 100644
--- a/src/cppcache/src/CacheableObjectPartList.cpp
+++ b/src/cppcache/src/CacheableObjectPartList.cpp
@@ -21,7 +21,9 @@
 #include "ThinClientRegion.hpp"
 #include "CacheableToken.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void CacheableObjectPartList::toData(DataOutput& output) const {
   // don't really care about toData() and should never get invoked
@@ -132,4 +134,6 @@ int8_t CacheableObjectPartList::DSFID() const {
 }
 
 uint32_t CacheableObjectPartList::objectSize() const { return 0; }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableObjectPartList.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableObjectPartList.hpp 
b/src/cppcache/src/CacheableObjectPartList.hpp
index 759d4d1..67596de 100644
--- a/src/cppcache/src/CacheableObjectPartList.hpp
+++ b/src/cppcache/src/CacheableObjectPartList.hpp
@@ -32,7 +32,9 @@
 /** @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ThinClientRegion;
 
 /**
@@ -138,6 +140,8 @@ class CacheableObjectPartList : public Cacheable {
 };
 
 typedef SharedPtr<CacheableObjectPartList> CacheableObjectPartListPtr;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GEMFIRE_CACHEABLEOBJECTPARTLIST_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableString.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableString.cpp 
b/src/cppcache/src/CacheableString.cpp
index e071170..60f1022 100644
--- a/src/cppcache/src/CacheableString.cpp
+++ b/src/cppcache/src/CacheableString.cpp
@@ -26,7 +26,7 @@
 #include <ace/ACE.h>
 #include <ace/OS.h>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 void CacheableString::toData(DataOutput& output) const {
   if (m_type == GF_STRING) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableToken.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableToken.cpp 
b/src/cppcache/src/CacheableToken.cpp
index 1358c04..b939773 100644
--- a/src/cppcache/src/CacheableToken.cpp
+++ b/src/cppcache/src/CacheableToken.cpp
@@ -23,7 +23,7 @@
 #include <gfcpp/CacheableString.hpp>
 #include "GemfireTypeIdsImpl.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 //---- statics
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableToken.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableToken.hpp 
b/src/cppcache/src/CacheableToken.hpp
index 1d7edf6..eeff5e4 100644
--- a/src/cppcache/src/CacheableToken.hpp
+++ b/src/cppcache/src/CacheableToken.hpp
@@ -20,7 +20,9 @@
 #include <gfcpp/gfcpp_globals.hpp>
 #include <gfcpp/Cacheable.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CPPCACHE_EXPORT CacheableToken;
 typedef SharedPtr<CacheableToken> CacheableTokenPtr;
@@ -124,6 +126,8 @@ class CPPCACHE_EXPORT CacheableToken : public Cacheable {
   void operator=(const CacheableToken& other);
   CacheableToken(const CacheableToken& other);
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheableUndefined.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CacheableUndefined.cpp 
b/src/cppcache/src/CacheableUndefined.cpp
index a9a5726..3d40dca 100644
--- a/src/cppcache/src/CacheableUndefined.cpp
+++ b/src/cppcache/src/CacheableUndefined.cpp
@@ -20,7 +20,9 @@
 #include <gfcpp/GemfireTypeIds.hpp>
 #include <GemfireTypeIdsImpl.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void CacheableUndefined::toData(DataOutput& output) const {}
 
@@ -37,4 +39,6 @@ int8_t CacheableUndefined::DSFID() const {
 }
 
 uint32_t CacheableUndefined::objectSize() const { return 0; }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CachedDeserializableHelper.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CachedDeserializableHelper.hpp 
b/src/cppcache/src/CachedDeserializableHelper.hpp
index 9f2937b..6eb30b4 100644
--- a/src/cppcache/src/CachedDeserializableHelper.hpp
+++ b/src/cppcache/src/CachedDeserializableHelper.hpp
@@ -22,7 +22,9 @@
 #include <gfcpp/ExceptionTypes.hpp>
 #include "GemfireTypeIdsImpl.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 /**
  * Helper class to deserialize bytes received from GFE in the form of
  * PREFER_BYTES_CACHED_DESERIALIZABLE = -65, or
@@ -93,7 +95,8 @@ class CachedDeserializableHelper : public Cacheable,
 };
 
 typedef SharedPtr<CachedDeserializableHelper> CachedDeserializableHelperPtr;
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // CACHEDDESERIALIZABLEHELPER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientConnectionRequest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientConnectionRequest.cpp 
b/src/cppcache/src/ClientConnectionRequest.cpp
index c80ceef..4470f82 100644
--- a/src/cppcache/src/ClientConnectionRequest.cpp
+++ b/src/cppcache/src/ClientConnectionRequest.cpp
@@ -18,7 +18,7 @@
 #include <gfcpp/DataOutput.hpp>
 #include <gfcpp/DataInput.hpp>
 #include "GemfireTypeIdsImpl.hpp"
-using namespace gemfire;
+using namespace apache::geode::client;
 void ClientConnectionRequest::toData(DataOutput& output) const {
   // output.writeASCII( m_servergroup.c_str() );
   // writeSetOfServerLocation( output );

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientConnectionRequest.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientConnectionRequest.hpp 
b/src/cppcache/src/ClientConnectionRequest.hpp
index 4a541cf..7bc8f46 100644
--- a/src/cppcache/src/ClientConnectionRequest.hpp
+++ b/src/cppcache/src/ClientConnectionRequest.hpp
@@ -22,7 +22,9 @@
 #include <set>
 #include "ServerLocation.hpp"
 #define _TEST_
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ClientConnectionRequest : public ServerLocationRequest {
  public:
 #ifdef _TEST_
@@ -60,5 +62,7 @@ class ClientConnectionRequest : public ServerLocationRequest {
   const std::set<TcrEndpoint*>& m_excludeServergroup;
 #endif
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientConnectionResponse.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientConnectionResponse.cpp 
b/src/cppcache/src/ClientConnectionResponse.cpp
index 1d9ebe9..3f72ade 100644
--- a/src/cppcache/src/ClientConnectionResponse.cpp
+++ b/src/cppcache/src/ClientConnectionResponse.cpp
@@ -17,7 +17,7 @@
 #include "ClientConnectionResponse.hpp"
 #include <gfcpp/DataOutput.hpp>
 #include <gfcpp/DataInput.hpp>
-using namespace gemfire;
+using namespace apache::geode::client;
 ClientConnectionResponse* ClientConnectionResponse::fromData(DataInput& input) 
{
   input.readBoolean(&m_serverFound);
   if (m_serverFound) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientConnectionResponse.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientConnectionResponse.hpp 
b/src/cppcache/src/ClientConnectionResponse.hpp
index 571dbbb..1ebce7b 100644
--- a/src/cppcache/src/ClientConnectionResponse.hpp
+++ b/src/cppcache/src/ClientConnectionResponse.hpp
@@ -19,7 +19,9 @@
 #include "ServerLocationResponse.hpp"
 #include "ServerLocation.hpp"
 #include <gfcpp/SharedPtr.hpp>
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ClientConnectionResponse : public ServerLocationResponse {
  public:
   ClientConnectionResponse()
@@ -43,5 +45,7 @@ class ClientConnectionResponse : public 
ServerLocationResponse {
   ServerLocation m_server;
 };
 typedef SharedPtr<ClientConnectionResponse> ClientConnectionResponsePtr;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientHealthStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientHealthStats.cpp 
b/src/cppcache/src/ClientHealthStats.cpp
index f5cf2b9..3ee38f9 100644
--- a/src/cppcache/src/ClientHealthStats.cpp
+++ b/src/cppcache/src/ClientHealthStats.cpp
@@ -17,7 +17,9 @@
 #include "ClientHealthStats.hpp"
 #include "CacheImpl.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void ClientHealthStats::toData(DataOutput& output) const {
   output.writeInt(static_cast<int32_t>(m_numGets));
@@ -80,4 +82,6 @@ ClientHealthStats::ClientHealthStats(int gets, int puts, int 
misses,
 }
 
 ClientHealthStats::~ClientHealthStats() {}
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientHealthStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientHealthStats.hpp 
b/src/cppcache/src/ClientHealthStats.hpp
index 2016430..a44838b 100644
--- a/src/cppcache/src/ClientHealthStats.hpp
+++ b/src/cppcache/src/ClientHealthStats.hpp
@@ -22,7 +22,9 @@
 #include <gfcpp/Log.hpp>
 #include <gfcpp/CacheableDate.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class ClientHealthStats : public Serializable {
  public:
@@ -83,6 +85,7 @@ class ClientHealthStats : public Serializable {
   int m_cpus;
   CacheableDatePtr m_updateTime;  // Last updateTime
 };
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // _CLIENT_HEALTH_STATS_HPP_INCLUDED_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientMetadata.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientMetadata.cpp 
b/src/cppcache/src/ClientMetadata.cpp
index 8b3463d..590e2d0 100644
--- a/src/cppcache/src/ClientMetadata.cpp
+++ b/src/cppcache/src/ClientMetadata.cpp
@@ -21,7 +21,9 @@
 #include <climits>
 #include <ace/OS.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 ClientMetadata::ClientMetadata(
     int totalNumBuckets, CacheableStringPtr colocatedWith,
@@ -383,4 +385,6 @@ BucketServerLocationPtr 
ClientMetadata::adviseRandomServerLocation() {
   }
   return NULLPTR;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientMetadata.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientMetadata.hpp 
b/src/cppcache/src/ClientMetadata.hpp
index 96f664b..8d3421c 100644
--- a/src/cppcache/src/ClientMetadata.hpp
+++ b/src/cppcache/src/ClientMetadata.hpp
@@ -30,7 +30,9 @@
 
 /*Stores the information such as partition attributes and meta data details*/
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ThinClientPoolDM;
 class ClientMetadata;
 
@@ -99,6 +101,8 @@ class CPPCACHE_EXPORT ClientMetadata : public SharedBase, 
public NonAssignable {
   BucketServerLocationPtr advisePrimaryServerLocation(int bucketId);
   BucketServerLocationPtr adviseRandomServerLocation();
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientMetadataService.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientMetadataService.cpp 
b/src/cppcache/src/ClientMetadataService.cpp
index 55511ab..46f95d6 100644
--- a/src/cppcache/src/ClientMetadataService.cpp
+++ b/src/cppcache/src/ClientMetadataService.cpp
@@ -22,7 +22,9 @@
 #include <cstdlib>
 #include <climits>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 const char* ClientMetadataService::NC_CMDSvcThread = "NC CMDSvcThread";
 ClientMetadataService::~ClientMetadataService() {
   delete m_regionQueue;
@@ -1006,4 +1008,6 @@ bool 
ClientMetadataService::isBucketMarkedForTimeout(const char* regionFullPath,
 
   return false;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientMetadataService.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientProxyMembershipID.cpp 
b/src/cppcache/src/ClientProxyMembershipID.cpp
index 723aff3..28c7130 100644
--- a/src/cppcache/src/ClientProxyMembershipID.cpp
+++ b/src/cppcache/src/ClientProxyMembershipID.cpp
@@ -30,7 +30,7 @@
 #define VMKIND 13
 #define ROLEARRLENGTH 0
 static int synch_counter = 2;
-using namespace gemfire;
+using namespace apache::geode::client;
 
 namespace {
 static class RandomInitializer {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientProxyMembershipID.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientProxyMembershipID.hpp 
b/src/cppcache/src/ClientProxyMembershipID.hpp
index f6903d2..bd70ee8 100644
--- a/src/cppcache/src/ClientProxyMembershipID.hpp
+++ b/src/cppcache/src/ClientProxyMembershipID.hpp
@@ -25,7 +25,9 @@
 #include <ace/OS.h>
 #include <string>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ClientProxyMembershipID;
 typedef SharedPtr<ClientProxyMembershipID> ClientProxyMembershipIDPtr;
 
@@ -139,6 +141,8 @@ class ClientProxyMembershipID : public 
DSMemberForVersionStamp {
   void readVersion(int flags, DataInput& input);
   void writeVersion(int16_t ordinal, DataOutput& output);
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __CLIENTPROXYMEMBERSHIPID_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientReplacementRequest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientReplacementRequest.cpp 
b/src/cppcache/src/ClientReplacementRequest.cpp
index 61554e6..a9cecd0 100644
--- a/src/cppcache/src/ClientReplacementRequest.cpp
+++ b/src/cppcache/src/ClientReplacementRequest.cpp
@@ -19,7 +19,7 @@
 #include <gfcpp/DataOutput.hpp>
 #include <gfcpp/DataInput.hpp>
 #include "GemfireTypeIdsImpl.hpp"
-using namespace gemfire;
+using namespace apache::geode::client;
 void ClientReplacementRequest::toData(DataOutput& output) const {
   ClientConnectionRequest::toData(output);
   this->m_serverLocation.toData(output);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientReplacementRequest.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ClientReplacementRequest.hpp 
b/src/cppcache/src/ClientReplacementRequest.hpp
index 318b76c..1d25768 100644
--- a/src/cppcache/src/ClientReplacementRequest.hpp
+++ b/src/cppcache/src/ClientReplacementRequest.hpp
@@ -23,7 +23,9 @@
 #include <set>
 #include "ServerLocation.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ClientReplacementRequest : public ClientConnectionRequest {
  public:
   ClientReplacementRequest(const std::string& serverName,
@@ -38,5 +40,7 @@ class ClientReplacementRequest : public 
ClientConnectionRequest {
  private:
   const ServerLocation m_serverLocation;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ConcurrentEntriesMap.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ConcurrentEntriesMap.cpp 
b/src/cppcache/src/ConcurrentEntriesMap.cpp
index 60610f0..d988026 100644
--- a/src/cppcache/src/ConcurrentEntriesMap.cpp
+++ b/src/cppcache/src/ConcurrentEntriesMap.cpp
@@ -21,7 +21,7 @@
 
 #include <algorithm>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 bool EntriesMap::boolVal = false;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ConcurrentEntriesMap.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ConcurrentEntriesMap.hpp 
b/src/cppcache/src/ConcurrentEntriesMap.hpp
index 309d8fc..9b9e336 100644
--- a/src/cppcache/src/ConcurrentEntriesMap.hpp
+++ b/src/cppcache/src/ConcurrentEntriesMap.hpp
@@ -24,7 +24,9 @@
 #include "ExpMapEntry.hpp"
 #include <gfcpp/RegionEntry.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class RegionInternal;
 
 /**
@@ -160,7 +162,8 @@ class CPPCACHE_EXPORT ConcurrentEntriesMap : public 
EntriesMap {
    */
   uint32_t totalSegmentRehashes() const;
 };  // class EntriesMap
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_IMPL_CONCURRENTENTRIESMAP_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/Condition.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Condition.cpp b/src/cppcache/src/Condition.cpp
index 3e5e53d..21e148f 100644
--- a/src/cppcache/src/Condition.cpp
+++ b/src/cppcache/src/Condition.cpp
@@ -17,7 +17,9 @@
 
 #include "Condition.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * Create a Condition protected by the mutex provided.
@@ -42,4 +44,6 @@ bool Condition::waitUntil(ACE_Time_Value* absoluteStopTime) {
   m_signaled = false;
   return result;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/Condition.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Condition.hpp b/src/cppcache/src/Condition.hpp
index 09a4ebf..5184a3a 100644
--- a/src/cppcache/src/Condition.hpp
+++ b/src/cppcache/src/Condition.hpp
@@ -21,7 +21,9 @@
 #include <ace/Condition_Recursive_Thread_Mutex.h>
 #include <ace/OS_NS_sys_time.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * Condition wrapper when you want an absolute signal or timeout condition.
@@ -68,6 +70,8 @@ class CPPCACHE_EXPORT Condition {
   /** Must be called with the mutex held. */
   inline void reset() { m_signaled = false; }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ConnectCounter.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ConnectCounter.cpp 
b/src/cppcache/src/ConnectCounter.cpp
index e3558ac..161d040 100644
--- a/src/cppcache/src/ConnectCounter.cpp
+++ b/src/cppcache/src/ConnectCounter.cpp
@@ -17,9 +17,13 @@
 
 #include "ConnectCounter.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 ConnectCounter::ConnectCounter() {}
 
 ConnectCounter::~ConnectCounter() {}
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ConnectCounter.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ConnectCounter.hpp 
b/src/cppcache/src/ConnectCounter.hpp
index c898d10..b3bd722 100644
--- a/src/cppcache/src/ConnectCounter.hpp
+++ b/src/cppcache/src/ConnectCounter.hpp
@@ -19,7 +19,9 @@
 
 #include <gfcpp/gfcpp_globals.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CPPCACHE_EXPORT ConnectCounter {
  public:
@@ -30,6 +32,8 @@ class CPPCACHE_EXPORT ConnectCounter {
   virtual void inc(const char* clientName) = 0;
   virtual void dec(const char* clientName) = 0;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/Connector.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Connector.hpp b/src/cppcache/src/Connector.hpp
index a8a6964..ee470a4 100644
--- a/src/cppcache/src/Connector.hpp
+++ b/src/cppcache/src/Connector.hpp
@@ -28,7 +28,9 @@ These are superseded by the connect-timeout system property 
for SR # 6525.
 #define DEFAULT_READ_TIMEOUT_SECS DEFAULT_TIMEOUT_SECONDS
 #define DEFAULT_WRITE_TIMEOUT DEFAULT_TIMEOUT_SECONDS
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class Connector {
  public:
   /* create one socket connection with settings */
@@ -99,6 +101,8 @@ class Connector {
   Connector(const Connector &);
   Connector &operator=(const Connector &);
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __CONNECTOR_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CppCacheLibrary.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CppCacheLibrary.cpp 
b/src/cppcache/src/CppCacheLibrary.cpp
index 820951c..157fdb8 100644
--- a/src/cppcache/src/CppCacheLibrary.cpp
+++ b/src/cppcache/src/CppCacheLibrary.cpp
@@ -38,11 +38,15 @@
 
 #include <string>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 void gf_log_libinit();
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 CppCacheLibrary::CppCacheLibrary() {
   // TODO: This should catch any exceptions, log it, and bail out..
@@ -58,7 +62,7 @@ CppCacheLibrary::CppCacheLibrary() {
     SerializationRegistry::init();
     // PdxTypeRegistry::init();
     // log( "Finished initializing CppCacheLibrary." );
-  } catch (gemfire::Exception& ge) {
+  } catch (apache::geode::client::Exception& ge) {
     ge.printStackTrace();
     throw;
   }
@@ -158,7 +162,7 @@ std::string CppCacheLibrary::getProductDir() {
             "Cannot determine location of product directory.\n"
             "Please set GFCPP environment variable.\n");
     fflush(stderr);
-    throw gemfire::IllegalStateException(
+    throw apache::geode::client::IllegalStateException(
         "Product installation directory "
         "not found. Please set GFCPP environment variable.");
   }
@@ -203,7 +207,8 @@ std::string CppCacheLibrary::getProductDir() {
   fprintf(stderr, "Cannot determine location of product directory.\n"
       "Please set GFCPP environment variable.\n");
   fflush(stderr);
-  throw gemfire::IllegalStateException("Product installation directory "
+  throw apache::geode::client::IllegalStateException("Product installation
+  directory "
       "not found. Please set GFCPP environment variable.");
       */
 }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CppCacheLibrary.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CppCacheLibrary.hpp 
b/src/cppcache/src/CppCacheLibrary.hpp
index df68954..8d16687 100644
--- a/src/cppcache/src/CppCacheLibrary.hpp
+++ b/src/cppcache/src/CppCacheLibrary.hpp
@@ -20,7 +20,9 @@
 #include <gfcpp/gfcpp_globals.hpp>
 #include <string>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 // initialize GEMFIRE runtime if it has not already been initialized.
 class CPPCACHE_EXPORT CppCacheLibrary {
@@ -45,7 +47,8 @@ class CPPCACHE_EXPORT CppCacheLibrary {
 
   static std::string getProductDir();
 };
-
-}; /* namespace gemfire */
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_IMPL_CPPCACHELIBRARY_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqAttributesFactory.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqAttributesFactory.cpp 
b/src/cppcache/src/CqAttributesFactory.cpp
index 1ff108e..6261cde 100644
--- a/src/cppcache/src/CqAttributesFactory.cpp
+++ b/src/cppcache/src/CqAttributesFactory.cpp
@@ -18,7 +18,7 @@
 #include <CqAttributesImpl.hpp>
 #include <gfcpp/ExceptionTypes.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 CqAttributesFactory::CqAttributesFactory() {
   m_cqAttributes = new CqAttributesImpl();

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqAttributesImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqAttributesImpl.cpp 
b/src/cppcache/src/CqAttributesImpl.cpp
index a8ab6b0..91eacc8 100644
--- a/src/cppcache/src/CqAttributesImpl.cpp
+++ b/src/cppcache/src/CqAttributesImpl.cpp
@@ -16,7 +16,7 @@
  */
 #include "CqAttributesImpl.hpp"
 #include <gfcpp/ExceptionTypes.hpp>
-using namespace gemfire;
+using namespace apache::geode::client;
 void CqAttributesImpl::getCqListeners(VectorOfCqListener& vl) {
   ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_mutex);
   vl.clear();

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqAttributesImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqAttributesImpl.hpp 
b/src/cppcache/src/CqAttributesImpl.hpp
index 777b2b5..77d6cde 100644
--- a/src/cppcache/src/CqAttributesImpl.hpp
+++ b/src/cppcache/src/CqAttributesImpl.hpp
@@ -29,7 +29,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * @class CqAttributesImpl CqAttributesImpl.hpp
@@ -70,7 +72,8 @@ class CPPCACHE_EXPORT CqAttributesImpl : public CqAttributes {
   bool m_dataPolicyHasBeenSet;
   ACE_Recursive_Thread_Mutex m_mutex;
 };
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __GEMFIRE_CQ_ATTRIBUTES_IMPL_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqAttributesMutatorImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqAttributesMutatorImpl.cpp 
b/src/cppcache/src/CqAttributesMutatorImpl.cpp
index d9065fe..737ae6c 100644
--- a/src/cppcache/src/CqAttributesMutatorImpl.cpp
+++ b/src/cppcache/src/CqAttributesMutatorImpl.cpp
@@ -16,7 +16,7 @@
  */
 #include "CqAttributesMutatorImpl.hpp"
 #include "CqAttributesImpl.hpp"
-using namespace gemfire;
+using namespace apache::geode::client;
 CqAttributesMutatorImpl::CqAttributesMutatorImpl(const CqAttributesPtr& impl)
     : m_cqAttributes(const_cast<CqAttributes*>(impl.ptr())) {}
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqAttributesMutatorImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqAttributesMutatorImpl.hpp 
b/src/cppcache/src/CqAttributesMutatorImpl.hpp
index 02f1ab8..912c387 100644
--- a/src/cppcache/src/CqAttributesMutatorImpl.hpp
+++ b/src/cppcache/src/CqAttributesMutatorImpl.hpp
@@ -27,7 +27,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * @class CqAttributesMutatorImpl CqAttributesMutatorImpl.hpp
@@ -73,7 +75,8 @@ class CPPCACHE_EXPORT CqAttributesMutatorImpl : public 
CqAttributesMutator {
  private:
   CqAttributesPtr m_cqAttributes;
 };
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __GEMFIRE_CQ_ATTRIBUTES_MUTATOR_IMPL_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqEventImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqEventImpl.cpp b/src/cppcache/src/CqEventImpl.cpp
index d8c890d..6f796db 100644
--- a/src/cppcache/src/CqEventImpl.cpp
+++ b/src/cppcache/src/CqEventImpl.cpp
@@ -20,7 +20,7 @@
 #include "ThinClientCacheDistributionManager.hpp"
 #include "TcrMessage.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 CqEventImpl::CqEventImpl(CqQueryPtr& cQuery,
                          CqOperation::CqOperationType baseOp,
                          CqOperation::CqOperationType cqOp,

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqEventImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqEventImpl.hpp b/src/cppcache/src/CqEventImpl.hpp
index c2df857..0e77229 100644
--- a/src/cppcache/src/CqEventImpl.hpp
+++ b/src/cppcache/src/CqEventImpl.hpp
@@ -31,7 +31,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * @cacheserver
@@ -96,7 +98,8 @@ class CqEventImpl : public CqEvent {
   CacheableBytesPtr m_deltaValue;
   EventIdPtr m_eventId;
 };
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __GEMFIRE_CQ_EVENT_IMPL_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqListener.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqListener.cpp b/src/cppcache/src/CqListener.cpp
index 5a8993f..e77a370 100644
--- a/src/cppcache/src/CqListener.cpp
+++ b/src/cppcache/src/CqListener.cpp
@@ -17,7 +17,7 @@
 
 #include <gfcpp/CqListener.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 CqListener::CqListener() {}
 void CqListener::onEvent(const CqEvent& aCqEvent) {}
 void CqListener::onError(const CqEvent& aCqEvent) {}

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqQueryImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqQueryImpl.cpp b/src/cppcache/src/CqQueryImpl.cpp
index 07f2967..5430e98 100644
--- a/src/cppcache/src/CqQueryImpl.cpp
+++ b/src/cppcache/src/CqQueryImpl.cpp
@@ -25,7 +25,7 @@
 #include "ThinClientRegion.hpp"
 #include "ReadWriteLock.hpp"
 #include "ThinClientRegion.hpp"
-using namespace gemfire;
+using namespace apache::geode::client;
 
 CqQueryImpl::CqQueryImpl(CqServicePtr& cqService, std::string& cqName,
                          std::string& queryString,

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqQueryImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqQueryImpl.hpp b/src/cppcache/src/CqQueryImpl.hpp
index d8a31b8..80b5e4a 100644
--- a/src/cppcache/src/CqQueryImpl.hpp
+++ b/src/cppcache/src/CqQueryImpl.hpp
@@ -41,7 +41,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * @class CqQueryImpl CqQueryImpl.hpp
@@ -266,7 +268,8 @@ class CqQueryImpl : public CqQuery {
   ThinClientBaseDM* m_tccdm;
   ProxyCachePtr m_proxyCache;
 };
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __GEMFIRE_CQ_QUERY_IMPL_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqQueryVsdStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqQueryVsdStats.cpp 
b/src/cppcache/src/CqQueryVsdStats.cpp
index 686c715..7ca1590 100644
--- a/src/cppcache/src/CqQueryVsdStats.cpp
+++ b/src/cppcache/src/CqQueryVsdStats.cpp
@@ -28,7 +28,9 @@ const char* cqStatsDesc = (const char*)"Statistics for this 
cq query";
 
 
////////////////////////////////////////////////////////////////////////////////
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 using namespace gemfire_statistics;
 
@@ -135,5 +137,6 @@ CqQueryVsdStats::~CqQueryVsdStats() {
     m_cqQueryVsdStats = NULL;
   }
 }
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqQueryVsdStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqQueryVsdStats.hpp 
b/src/cppcache/src/CqQueryVsdStats.hpp
index 1039746..4a72a83 100644
--- a/src/cppcache/src/CqQueryVsdStats.hpp
+++ b/src/cppcache/src/CqQueryVsdStats.hpp
@@ -24,7 +24,9 @@
 
 #include <gfcpp/CqStatistics.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 using namespace gemfire_statistics;
 
@@ -100,6 +102,8 @@ class CqQueryStatType {
 
   inline int32_t getNumEventsId() { return m_numEventsId; }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_CQ_QUERY_STATS_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqService.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqService.cpp b/src/cppcache/src/CqService.cpp
index ef3550a..57e190c 100644
--- a/src/cppcache/src/CqService.cpp
+++ b/src/cppcache/src/CqService.cpp
@@ -24,7 +24,7 @@
 #include <gfcpp/CqServiceStatistics.hpp>
 #include "ThinClientPoolDM.hpp"
 #include <gfcpp/CqStatusListener.hpp>
-using namespace gemfire;
+using namespace apache::geode::client;
 
 CqService::CqService(ThinClientBaseDM* tccdm)
     : m_tccdm(tccdm), m_notificationSema(1), m_stats(new CqServiceVsdStats()) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqService.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqServiceVsdStats.cpp 
b/src/cppcache/src/CqServiceVsdStats.cpp
index c372c47..5155fb5 100644
--- a/src/cppcache/src/CqServiceVsdStats.cpp
+++ b/src/cppcache/src/CqServiceVsdStats.cpp
@@ -28,7 +28,9 @@ const char* cqServiceStatsDesc = (const char*)"Statistics for 
this cq Service";
 
 
////////////////////////////////////////////////////////////////////////////////
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 using namespace gemfire_statistics;
 
@@ -143,5 +145,6 @@ CqServiceVsdStats::~CqServiceVsdStats() {
     m_cqServiceVsdStats = NULL;
   }
 }
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqServiceVsdStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqServiceVsdStats.hpp 
b/src/cppcache/src/CqServiceVsdStats.hpp
index 869cac0..170f5b1 100644
--- a/src/cppcache/src/CqServiceVsdStats.hpp
+++ b/src/cppcache/src/CqServiceVsdStats.hpp
@@ -24,7 +24,9 @@
 #include "SpinLock.hpp"
 #include <gfcpp/CqServiceStatistics.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 using namespace gemfire_statistics;
 
@@ -137,6 +139,8 @@ class CqServiceStatType {
 
   inline int32_t getNumCqsStoppedId() { return m_numCqsStoppedId; }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_CQ_SERVICE_STATS_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqState.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqState.cpp b/src/cppcache/src/CqState.cpp
index 76179ea..f13c5f9 100644
--- a/src/cppcache/src/CqState.cpp
+++ b/src/cppcache/src/CqState.cpp
@@ -16,7 +16,7 @@
  */
 #include <gfcpp/CqState.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 bool CqState::isRunning() const { return (m_state == RUNNING); }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqStatusListener.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqStatusListener.cpp 
b/src/cppcache/src/CqStatusListener.cpp
index ba6eb77..1dcc98f 100644
--- a/src/cppcache/src/CqStatusListener.cpp
+++ b/src/cppcache/src/CqStatusListener.cpp
@@ -17,8 +17,12 @@
 
 #include <gfcpp/CqStatusListener.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void CqStatusListener::onCqDisconnected() {}
 void CqStatusListener::onCqConnected() {}
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DSMemberForVersionStamp.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DSMemberForVersionStamp.hpp 
b/src/cppcache/src/DSMemberForVersionStamp.hpp
index 8894c6e..d8545a9 100644
--- a/src/cppcache/src/DSMemberForVersionStamp.hpp
+++ b/src/cppcache/src/DSMemberForVersionStamp.hpp
@@ -21,7 +21,9 @@
 #include <gfcpp/CacheableKey.hpp>
 #include <string>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class DSMemberForVersionStamp;
 typedef SharedPtr<DSMemberForVersionStamp> DSMemberForVersionStampPtr;
 
@@ -37,6 +39,8 @@ class DSMemberForVersionStamp : public CacheableKey {
   /** return the hashcode for this key. */
   virtual uint32_t hashcode() const = 0;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __DSMemberForVersionStamp_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DataInput.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DataInput.cpp b/src/cppcache/src/DataInput.cpp
index 822f8d9..2bfdf72 100644
--- a/src/cppcache/src/DataInput.cpp
+++ b/src/cppcache/src/DataInput.cpp
@@ -19,9 +19,13 @@
 
 #include <SerializationRegistry.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void DataInput::readObjectInternal(SerializablePtr& ptr, int8_t typeId) {
   ptr = SerializationRegistry::deserialize(*this, typeId);
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DataOutput.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DataOutput.cpp b/src/cppcache/src/DataOutput.cpp
index 2064ac7..ddbec75 100644
--- a/src/cppcache/src/DataOutput.cpp
+++ b/src/cppcache/src/DataOutput.cpp
@@ -23,7 +23,9 @@
 #include <ace/Recursive_Thread_Mutex.h>
 #include <vector>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 ACE_Recursive_Thread_Mutex g_bigBufferLock;
 uint32_t DataOutput::m_highWaterMark = 50 * 1024 * 1024;
@@ -122,4 +124,6 @@ void DataOutput::writeObjectInternal(const Serializable* 
ptr, bool isDelta) {
 void DataOutput::acquireLock() { g_bigBufferLock.acquire(); }
 
 void DataOutput::releaseLock() { g_bigBufferLock.release(); }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/Delta.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Delta.cpp b/src/cppcache/src/Delta.cpp
index 2c8d254..fc1cc06 100644
--- a/src/cppcache/src/Delta.cpp
+++ b/src/cppcache/src/Delta.cpp
@@ -23,7 +23,7 @@
 
 #include <gfcpp/Delta.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 DeltaPtr Delta::clone() {
   DataOutput out;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DiffieHellman.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DiffieHellman.cpp 
b/src/cppcache/src/DiffieHellman.cpp
index 09addaa..e58d286 100644
--- a/src/cppcache/src/DiffieHellman.cpp
+++ b/src/cppcache/src/DiffieHellman.cpp
@@ -20,7 +20,9 @@
 #include <gfcpp/ExceptionTypes.hpp>
 #include <gfcpp/SystemProperties.hpp>
 #include <ace/Guard_T.h>
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 ACE_DLL DiffieHellman::m_dll;
 bool DiffieHellman::m_inited = false;
@@ -194,5 +196,6 @@ bool DiffieHellman::verify(const CacheableStringPtr& 
subject,
 
   return result;
 }
-
-};  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DiffieHellman.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DiffieHellman.hpp 
b/src/cppcache/src/DiffieHellman.hpp
index ea263f3..0ae6719 100644
--- a/src/cppcache/src/DiffieHellman.hpp
+++ b/src/cppcache/src/DiffieHellman.hpp
@@ -34,7 +34,9 @@
 const char SecurityClientDhAlgo[] = "security-client-dhalgo";
 const char SecurityClientKsPath[] = "security-client-kspath";
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class DiffieHellman {
   static ACE_Recursive_Thread_Mutex s_mutex;
@@ -103,7 +105,8 @@ class DiffieHellman {
   static ACE_DLL m_dll;
 
 };  // class DiffieHellman
-
-};  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __DIFFIEHELLMAN__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DiskPolicyType.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DiskPolicyType.cpp 
b/src/cppcache/src/DiskPolicyType.cpp
index 880e92f..52e2b3f 100644
--- a/src/cppcache/src/DiskPolicyType.cpp
+++ b/src/cppcache/src/DiskPolicyType.cpp
@@ -18,7 +18,7 @@
 #include <gfcpp/DiskPolicyType.hpp>
 #include "ace/OS.h"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 const char* DiskPolicyType::names[] = {"none", "overflows", "persist", NULL};
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DiskStoreId.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DiskStoreId.cpp b/src/cppcache/src/DiskStoreId.cpp
index c65ff9f..cf5b2e7 100644
--- a/src/cppcache/src/DiskStoreId.cpp
+++ b/src/cppcache/src/DiskStoreId.cpp
@@ -18,7 +18,9 @@
 #include "DiskStoreId.hpp"
 #include <ace/OS.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 std::string DiskStoreId::getHashKey() {
   if (m_hashCode.size() == 0) {
     char hashCode[128] = {0};
@@ -38,4 +40,6 @@ std::string DiskStoreId::getHashKey() {
   }
   return m_hashCode;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DiskStoreId.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DiskStoreId.hpp b/src/cppcache/src/DiskStoreId.hpp
index 1435b8d..8e2ecbe 100644
--- a/src/cppcache/src/DiskStoreId.hpp
+++ b/src/cppcache/src/DiskStoreId.hpp
@@ -22,7 +22,9 @@
 #include "DSMemberForVersionStamp.hpp"
 #include "GemfireTypeIdsImpl.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class DiskStoreId : public DSMemberForVersionStamp {
  public:
@@ -105,6 +107,8 @@ class DiskStoreId : public DSMemberForVersionStamp {
   int64_t m_mostSig;
   int64_t m_leastSig;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __DiskStoreId_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DiskVersionTag.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DiskVersionTag.hpp 
b/src/cppcache/src/DiskVersionTag.hpp
index 27acd55..ba0de2d 100644
--- a/src/cppcache/src/DiskVersionTag.hpp
+++ b/src/cppcache/src/DiskVersionTag.hpp
@@ -21,7 +21,9 @@
 #include "GemfireTypeIdsImpl.hpp"
 #include "DiskStoreId.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class RegionInternal;
 class CacheImpl;
@@ -72,6 +74,8 @@ class DiskVersionTag : public VersionTag {
       : VersionTag(entryVersion, regionVersionHighBytes, regionVersionLowBytes,
                    internalMemId, previousMemId) {}
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __DISKVERSIONTAG_HPP__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DistributedSystem.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DistributedSystem.cpp 
b/src/cppcache/src/DistributedSystem.cpp
index 2f0485a..3edb9ab 100644
--- a/src/cppcache/src/DistributedSystem.cpp
+++ b/src/cppcache/src/DistributedSystem.cpp
@@ -41,7 +41,7 @@
 
 #include "version.h"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace gemfire_statistics;
 
 DistributedSystemPtr* DistributedSystem::m_instance_ptr = NULL;
@@ -57,7 +57,9 @@ StatisticsManager* g_statMngr = NULL;
 SystemProperties* g_sysProps = NULL;
 }  // namespace
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 void setLFH() {
 #ifdef _WIN32
   static HINSTANCE kernelMod = NULL;
@@ -103,7 +105,9 @@ void setLFH() {
   }
 #endif
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 DistributedSystem::DistributedSystem(const char* name) : m_name(NULL) {
   LOGDEBUG("DistributedSystem::DistributedSystem");
@@ -266,7 +270,7 @@ DistributedSystemPtr DistributedSystem::connect(
 
   try {
     m_impl->connect();
-  } catch (const gemfire::Exception& e) {
+  } catch (const apache::geode::client::Exception& e) {
     LOGERROR("Exception caught during client initialization: %s",
              e.getMessage());
     std::string msg = "DistributedSystem::connect: caught exception: ";
@@ -308,7 +312,7 @@ void DistributedSystem::disconnect() {
     if (cache != NULLPTR && !cache->isClosed()) {
       cache->close();
     }
-  } catch (const gemfire::Exception& e) {
+  } catch (const apache::geode::client::Exception& e) {
     LOGWARN("Exception while closing: %s: %s", e.getName(), e.getMessage());
   }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DistributedSystemImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DistributedSystemImpl.cpp 
b/src/cppcache/src/DistributedSystemImpl.cpp
index d088eb3..de918e9 100644
--- a/src/cppcache/src/DistributedSystemImpl.cpp
+++ b/src/cppcache/src/DistributedSystemImpl.cpp
@@ -18,7 +18,7 @@
 #include "DistributedSystemImpl.hpp"
 #include <gfcpp/SystemProperties.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // guard for connect/disconnect
 extern ACE_Recursive_Thread_Mutex* g_disconnectLock;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/DistributedSystemImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DistributedSystemImpl.hpp 
b/src/cppcache/src/DistributedSystemImpl.hpp
index 4310937..4b7ecb3 100644
--- a/src/cppcache/src/DistributedSystemImpl.hpp
+++ b/src/cppcache/src/DistributedSystemImpl.hpp
@@ -36,7 +36,9 @@
 #include <sys/prctl.h>
 #endif
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class SystemProperties;
 
 /**
@@ -132,6 +134,8 @@ class CPPCACHE_EXPORT DistributedSystemImpl : public 
SharedBase {
   static volatile bool m_isCliCallbackSet;
   static std::map<int, CliCallbackMethod> m_cliCallbackMap;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __IMPL_DISTRIBUTEDSYSTEM_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EntriesMap.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EntriesMap.hpp b/src/cppcache/src/EntriesMap.hpp
index ea8386c..026fc12 100644
--- a/src/cppcache/src/EntriesMap.hpp
+++ b/src/cppcache/src/EntriesMap.hpp
@@ -25,7 +25,9 @@
 #include "MapSegment.hpp"
 #include <gfcpp/RegionEntry.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 #define SYNCHRONIZE_SEGMENT_FOR_KEY(keyPtr) \
   SegmentMutexGuard 
_segment_guard(((EntriesMap*)m_entries)->segmentFor(keyPtr))
@@ -169,7 +171,8 @@ class CPPCACHE_EXPORT EntriesMap {
   inline const EntryFactory* getEntryFactory() const { return m_entryFactory; }
 
 };  // class EntriesMap
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_IMPL_ENTRIESMAP_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EntriesMapFactory.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EntriesMapFactory.cpp 
b/src/cppcache/src/EntriesMapFactory.cpp
index 9be10c6..31c7884 100644
--- a/src/cppcache/src/EntriesMapFactory.cpp
+++ b/src/cppcache/src/EntriesMapFactory.cpp
@@ -24,7 +24,7 @@
 //#include <gfcpp/ExpirationAction.hpp>
 #include <gfcpp/SystemProperties.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /**
  * @brief Return a ConcurrentEntriesMap if no LRU, otherwise return a

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EntriesMapFactory.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EntriesMapFactory.hpp 
b/src/cppcache/src/EntriesMapFactory.hpp
index 5553256..38adbda 100644
--- a/src/cppcache/src/EntriesMapFactory.hpp
+++ b/src/cppcache/src/EntriesMapFactory.hpp
@@ -21,7 +21,9 @@
 #include "EntriesMap.hpp"
 #include <gfcpp/RegionAttributes.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CPPCACHE_EXPORT EntriesMapFactory {
  public:
@@ -36,7 +38,8 @@ class CPPCACHE_EXPORT EntriesMapFactory {
   EntriesMapFactory() {}
 
 };  // class
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __GEMFIRE_IMPL_ENTRIESMAPFACTORY_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EntryEvent.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EntryEvent.cpp b/src/cppcache/src/EntryEvent.cpp
index 303988b..867630c 100644
--- a/src/cppcache/src/EntryEvent.cpp
+++ b/src/cppcache/src/EntryEvent.cpp
@@ -17,7 +17,9 @@
 #include <gfcpp/EntryEvent.hpp>
 #include <CacheableToken.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 EntryEvent::EntryEvent(const RegionPtr& region, const CacheableKeyPtr& key,
                        const CacheablePtr& oldValue,
                        const CacheablePtr& newValue,
@@ -37,4 +39,6 @@ EntryEvent::EntryEvent()
      * CID 28923: Uninitialized scalar field (UNINIT_CTOR)
      */
     : m_remoteOrigin(false) {}
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EntryExpiryHandler.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EntryExpiryHandler.cpp 
b/src/cppcache/src/EntryExpiryHandler.cpp
index abd1281..b834cf1 100644
--- a/src/cppcache/src/EntryExpiryHandler.cpp
+++ b/src/cppcache/src/EntryExpiryHandler.cpp
@@ -28,7 +28,7 @@
 
 #include "RegionInternal.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 EntryExpiryHandler::EntryExpiryHandler(RegionInternalPtr& rptr,
                                        MapEntryImplPtr& entryPtr,

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EntryExpiryHandler.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EntryExpiryHandler.hpp 
b/src/cppcache/src/EntryExpiryHandler.hpp
index c093a2b..f63053c 100644
--- a/src/cppcache/src/EntryExpiryHandler.hpp
+++ b/src/cppcache/src/EntryExpiryHandler.hpp
@@ -28,7 +28,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 /**
  * @class EntryExpiryTask EntryExpiryTask.hpp
  *
@@ -68,5 +70,7 @@ class CPPCACHE_EXPORT EntryExpiryHandler : public 
ACE_Event_Handler {
   // perform the actual expiration action
   void DoTheExpirationAction(const CacheableKeyPtr& key);
 };
-};      // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // ifndef _GEMFIRE_ENTRYEXPIRYTASK_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EnumInfo.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EnumInfo.cpp b/src/cppcache/src/EnumInfo.cpp
index bc5767c..6bbd59f 100644
--- a/src/cppcache/src/EnumInfo.cpp
+++ b/src/cppcache/src/EnumInfo.cpp
@@ -18,7 +18,9 @@
 #include "Utils.hpp"
 #include "GemfireTypeIdsImpl.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 EnumInfo::~EnumInfo() {}
 
@@ -61,13 +63,13 @@ bool EnumInfo::operator==(const CacheableKey &other) const {
   return true;
 }
 
-void EnumInfo::toData(gemfire::DataOutput &output) const {
+void EnumInfo::toData(apache::geode::client::DataOutput &output) const {
   output.writeObject(m_enumClassName);
   output.writeObject(m_enumName);
   output.writeInt(m_ordinal);
 }
 
-Serializable *EnumInfo::fromData(gemfire::DataInput &input) {
+Serializable *EnumInfo::fromData(apache::geode::client::DataInput &input) {
   input.readObject(m_enumClassName);
   input.readObject(m_enumName);
   input.readInt(&m_ordinal);
@@ -77,4 +79,6 @@ Serializable *EnumInfo::fromData(gemfire::DataInput &input) {
 int8_t EnumInfo::DSFID() const {
   return static_cast<int8_t>(GemfireTypeIdsImpl::FixedIDByte);
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EnumInfo.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EnumInfo.hpp b/src/cppcache/src/EnumInfo.hpp
index 5ee638a..0fe3e77 100644
--- a/src/cppcache/src/EnumInfo.hpp
+++ b/src/cppcache/src/EnumInfo.hpp
@@ -21,7 +21,9 @@
 #include <gfcpp/CacheableString.hpp>
 #include <gfcpp/CacheableKey.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CPPCACHE_EXPORT EnumInfo : public CacheableKey {
  private:
@@ -57,6 +59,8 @@ class CPPCACHE_EXPORT EnumInfo : public CacheableKey {
   int32_t getEnumOrdinal() const { return m_ordinal; }
 };
 typedef SharedPtr<EnumInfo> EnumInfoPtr;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ENUM_INFO_HPP

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EventId.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EventId.cpp b/src/cppcache/src/EventId.cpp
index c82cc55..8e8fc3f 100644
--- a/src/cppcache/src/EventId.cpp
+++ b/src/cppcache/src/EventId.cpp
@@ -23,7 +23,9 @@
 #include <ace/OS.h>
 #include <ace/INET_Addr.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 // to be used only with ACE_TSS<> or WinTSS<>
 class EventIdTSS {
@@ -183,4 +185,6 @@ size_t EventId::logString(char* buffer, size_t maxLength) 
const {
                           ", seq=%" PRIi64 " )",
                           m_eidThr, m_eidSeq);
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EventId.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EventId.hpp b/src/cppcache/src/EventId.hpp
index e1b2be5..c36f8ef 100644
--- a/src/cppcache/src/EventId.hpp
+++ b/src/cppcache/src/EventId.hpp
@@ -29,7 +29,9 @@
 /** @file
 */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * EventID "token" with a Distributed Member ID, Thread ID and per-thread
@@ -145,6 +147,8 @@ class CPPCACHE_EXPORT EventId : public Cacheable {
   void operator=(const EventId& other);
   EventId(const EventId& other);
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //_GEMFIRE_EVENTID_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EventIdMap.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EventIdMap.cpp b/src/cppcache/src/EventIdMap.cpp
index 64f4ff4..1ccb790 100644
--- a/src/cppcache/src/EventIdMap.cpp
+++ b/src/cppcache/src/EventIdMap.cpp
@@ -16,7 +16,7 @@
  */
 #include "EventIdMap.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 EventIdMap::~EventIdMap() { clear(); }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/EventIdMap.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/EventIdMap.hpp b/src/cppcache/src/EventIdMap.hpp
index 504e636..7452935 100644
--- a/src/cppcache/src/EventIdMap.hpp
+++ b/src/cppcache/src/EventIdMap.hpp
@@ -29,7 +29,9 @@
 #include <vector>
 #include <utility>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class EventSource;
 class EventSequence;
@@ -194,7 +196,8 @@ class CPPCACHE_EXPORT EventSequence : public SharedBase {
 
   bool operator<=(const EventSequence &rhs) const;
 };
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __EVENT_ID_MAP_HPP__

Reply via email to
diff --git a/src/cppcache/src/CacheImpl.hpp b/src/cppcache/src/CacheImpl.hpp
index f120bbb..b682519 100644
--- a/src/cppcache/src/CacheImpl.hpp
+++ b/src/cppcache/src/CacheImpl.hpp
@@ -51,7 +51,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CacheFactory;
 class ExpiryTaskManager;
@@ -77,7 +79,7 @@ class ExpiryTaskManager;
 
 /* adongre
  * CID 28711: Other violation (MISSING_ASSIGN)
  * Class "gemfire::CacheImpl" owns resources that are managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
  *
@@ -335,6 +337,7 @@ class CPPCACHE_EXPORT CacheImpl : private NonCopyable, 
private NonAssignable {
   friend class CacheFactory;
   friend class Cache;
 };
-
-};      // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // ifndef __GEMFIRE_CACHEIMPL_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CacheListener.cpp
----------------------------------------------------------------------
@@ -77,7 +79,7 @@ class ExpiryTaskManager;
 /* adongre
  * CID 28711: Other violation (MISSING_ASSIGN)
- * Class "gemfire::CacheImpl" owns resources that are managed
+ * Class "apache::geode::client::CacheImpl" owns resources that are managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
diff --git a/src/cppcache/src/ClientMetadataService.hpp 
b/src/cppcache/src/ClientMetadataService.hpp
index 85cd685..8f97bcb 100644
--- a/src/cppcache/src/ClientMetadataService.hpp
+++ b/src/cppcache/src/ClientMetadataService.hpp
@@ -31,7 +31,9 @@
 #include "DistributedSystemImpl.hpp"
 #include "NonCopyable.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class ClienMetadata;
 
@@ -83,11 +85,13 @@ class PRbuckets {
 
 /* adongre
  * CID 28726: Other violation (MISSING_COPY)
  * Class "gemfire::ClientMetadataService" owns resources that are managed
  * in its constructor and destructor but has no user-written copy constructor.
  *
  * CID 28712: Other violation (MISSING_ASSIGN)
  * Class "gemfire::ClientMetadataService" owns resources that are managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
  *
@@ -199,6 +203,8 @@ class ClientMetadataService : public ACE_Task_Base,
   uint32_t m_bucketWaitTimeout;
   static const char* NC_CMDSvcThread;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ClientProxyMembershipID.cpp
----------------------------------------------------------------------
@@ -83,11 +85,13 @@ class PRbuckets {
 /* adongre
  * CID 28726: Other violation (MISSING_COPY)
- * Class "gemfire::ClientMetadataService" owns resources that are managed
+ * Class "apache::geode::client::ClientMetadataService" owns resources that are
+ * managed
  * in its constructor and destructor but has no user-written copy constructor.
  *
@@ -83,11 +85,13 @@ class PRbuckets {
  *
  * CID 28712: Other violation (MISSING_ASSIGN)
- * Class "gemfire::ClientMetadataService" owns resources that are managed
+ * Class "apache::geode::client::ClientMetadataService" owns resources that are
+ * managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
diff --git a/src/cppcache/src/CqService.hpp b/src/cppcache/src/CqService.hpp
index b4b6cbc..db9c02b 100644
--- a/src/cppcache/src/CqService.hpp
+++ b/src/cppcache/src/CqService.hpp
@@ -45,7 +45,9 @@
  * @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * @class CqService CqService.hpp
@@ -56,11 +58,13 @@ namespace gemfire {
 
 /* adongre
  * CID 28727: Other violation (MISSING_COPY)
  * Class "gemfire::CqService" owns resources that are managed in its
  * constructor and destructor but has no user-written copy constructor.
  *
  * CID 28713: Other violation (MISSING_ASSIGN)
- * Class "gemfire::CqService" owns resources that are managed in its 
constructor
+ * Class "apache::geode::client::CqService" owns resources that are managed in
+ * its constructor
  * and destructor but has no user-written assignment operator.
  *
  * FIX : Make the class NonCopyable
@@ -253,7 +257,8 @@ class CPPCACHE_EXPORT CqService : public SharedBase,
 };
 
 typedef SharedPtr<CqService> CqServicePtr;
-
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __GEMFIRE_CQ_SERVICE_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/CqServiceVsdStats.cpp
----------------------------------------------------------------------
@@ -56,11 +58,13 @@ namespace gemfire {
 /* adongre
  * CID 28727: Other violation (MISSING_COPY)
- * Class "gemfire::CqService" owns resources that are managed in its
+ * Class "apache::geode::client::CqService" owns resources that are managed in
+ * its
  * constructor and destructor but has no user-written copy constructor.
  *